@@ -47,7 +47,7 @@ use Template;
 use Carp;
 use Data::Dumper;
 
-our $VERSION = 0.36;
+our $VERSION = 0.37;
 
 sub swit_startup {}
 
@@ -158,6 +158,13 @@ sub swit_schedule {
 	});
 }
 
+sub swit_hostport {
+	my ($class, $r) = @_;
+	my $res = $r->get_server_name;
+	$res .= ":" . $r->get_server_port if $r->get_server_port != 80;
+	return $res;
+}
+
 1;
 
 =head1 BUGS
